/*****************************************************************************/
/*                        WiNRADiO G39DDC EXCELSIOR                          */
/*                                SDK DEMO                                   */
/*                             Main GUI window                               */
/*                        (C) Copyright RADIXON 2014                         */
/*****************************************************************************/

#ifndef __U_MAINWINDOW_H__
#define __U_MAINWINDOW_H__

#include <wx/wx.h>
#include <wx/sizer.h>
#include <wx/tglbtn.h>
#include <wx/combobox.h>
#include "u_receiver.h"
#include "u_spectrum.h"
#include "u_rxpanel.h"
#include "u_swpspectrum.h"

class TMainWindow:public wxFrame,public TReceiverCallback
{
public:
    TMainWindow(TReceiver *Receiver);
    virtual ~TMainWindow(void);
private:    
    TReceiver           *m_Receiver;

    wxBoxSizer          *m_MainSizer;       
    wxBoxSizer          *m_IFSizerTop;
    wxBoxSizer          *m_IFSizerBottom;
    wxBoxSizer          *m_RXSizer;

    wxToggleButton      **m_BRX;

    TSpectrum           *m_IFSpectrum;
    wxToggleButton      *m_BSpectrum;
    wxToggleButton      *m_BSweeper;
    wxStaticText        *m_LAttenuator;
    wxComboBox          *m_CBAttenuator;
    wxToggleButton      *m_BPreamp;
    wxToggleButton      *m_BPower;
    wxStaticText        *m_LRBW;
    wxComboBox          *m_CBIFRBW;
    wxButton            *m_BIFDown;
    wxButton            *m_BIFUp;
    TSwpSpectrum        *m_SwpSpectrum;
    wxComboBox          *m_CBSwpRBW;
    wxStaticText        *m_LSwpStart;
    TFrequencyEdit      *m_ESwpStart;
    wxStaticText        *m_LSwpEnd;
    TFrequencyEdit      *m_ESwpEnd;
    wxToggleButton      *m_BSwpStart;
    wxButton            *m_BSwpStop;
    wxToggleButton      *m_BSwpLoop;
    wxButton            *m_BSwpClear;

    TRXPanel            **m_RXPanels;
    G39DDC_DEVICE_INFO  m_DeviceInfo;
    TRXPanel            *m_ActiveRXPanel;
    wxTimer             m_PowerStateTimer;
    wxTimer             m_ConnTimer;
    wxTimer             m_InitPowerOnTimer;
    bool                m_SwpLoop;

    virtual void ReceiverCallback_Event(TReceiverEvent Event);
    virtual void ReceiverCallback_ChannelEvent(uint32_t Channel,TChannelEvent Event);
    virtual void ReceiverCallback_DDC1Spectrum(uint32_t Channel,float *Data,uint32_t Count,double Range,double Offset);
    virtual void ReceiverCallback_DDC2Spectrum(uint32_t Channel,float *Data,uint32_t Count,double Range,double Offset);
    virtual void ReceiverCallback_AudioSpectrum(uint32_t Channel,float *Data,uint32_t Count,uint32_t Range);
    virtual void ReceiverCallback_IFSpectrum(float *Data,uint32_t Count,double Range,double Offset);
    virtual void ReceiverCallback_Audio(uint32_t Channel,const float *Samples,uint32_t Count);
    virtual void ReceiverCallbask_Sweeper(float *Data,uint32_t Count);
    virtual bool ReceiverCallback_SweeperQueryEnd(void);


    void Initialize(void);
    void UpdateBottomPanel(void);
    void UpdateState(void);
    void UpdateActiveChannel(void);
    void UpdateHFUHF(void);
    void UpdateAttenuatorState(void);
    void UpdatePreamplifierState(void);
    void UpdateFrontEndFrequency(void);
    void UpdateIFRBWIndex(void);

    void UpdateDDC1Frequency(uint32_t Channel);
    void UpdateDDC1(uint32_t Channel);

    void UpdateSwpState(void);


    void OnButtonClick(wxCommandEvent &Event);
    void OnRXButtonClick(wxCommandEvent &Event);
    void OnComboBoxChanged(wxCommandEvent &Event);
    void OnIFSpectrumTune(TSpectrumTuneEvent &Event);
    void OnSwpSpectrumTune(TSpectrumTuneEvent &Event);
    void OnTimer(wxTimerEvent& Event);
    void OnNumericEditChanged(wxNotifyEvent &Event);
    void OnStopSweeper(wxCommandEvent &Event);

    DECLARE_EVENT_TABLE()
};

#endif

