/*****************************************************************************/
/*                        WiNRADiO G39DDC EXCELSIOR                          */
/*                                SDK DEMO                                   */
/*                           Channel (RX) panel                              */
/*                        (C) Copyright RADIXON 2014                         */
/*****************************************************************************/

#ifndef __U_RXPANEL_H__
#define __U_RXPANEL_H__

#include <wx/wx.h>
#include <wx/sizer.h>
#include <wx/tglbtn.h>
#include "u_receiver.h"
#include "u_spectrum.h"
#include "u_frequencyedit.h"
#include "u_intedit.h"
#include "u_floatedit.h"
#include "u_waveout.h"


class TRXPanel:public wxPanel
{
public:
    void UpdateState(void);
    void ReceiverCallback_ChannelEvent(TChannelEvent Event);
    void ReceiverCallback_DDC1Spectrum(float *Data,uint32_t Count,double Range,double Offset);
    void ReceiverCallback_DDC2Spectrum(float *Data,uint32_t Count,double Range,double Offset);
    void ReceiverCallback_AudioSpectrum(float *Data,uint32_t Count,uint32_t Range);
    void ReceiverCallback_Audio(const float *Samples,uint32_t Count);
    void Initialize(void);


    TRXPanel(wxWindow *Parent,TReceiver *Receiver,uint32_t Channel);
    ~TRXPanel(void);
private:    
    TReceiver           *m_Receiver;
    uint32_t            m_Channel;
    G39DDC_DEVICE_INFO  m_DeviceInfo;
    wxBoxSizer          *m_MainSizer; 
    wxBoxSizer          *m_DDC2AudioSizer;
    wxBoxSizer          *m_DDC2Sizer;
    wxBoxSizer          *m_AudioSizer;
    wxBoxSizer          *m_DDC1Sizer;
    wxBoxSizer          *m_DDC1SizerTop;
    wxBoxSizer          *m_DDC2SizerTop;
    wxBoxSizer          *m_AudioSizerTop;

    TFrequencyEdit      *m_EFrequency;

    wxToggleButton      **m_BMode;


    TSpectrum           *m_DDC1Spectrum;
    wxStaticText        *m_LDDC1BW;
    wxComboBox          *m_CBDDC1BW;
    wxStaticText        *m_LDDC1RBW;
    wxComboBox          *m_CBDDC1RBW;
    
    

    TSpectrum           *m_DDC2Spectrum;
    wxStaticText        *m_LDDC2BW;
    wxComboBox          *m_CBDDC2BW;


    TSpectrum           *m_AudioSpectrum;
    wxStaticText        *m_LASR;
    wxComboBox          *m_CBASR;

    wxStaticText        *m_LDEMBW;
    TFrequencyEdit      *m_EDEMBW;

    wxStaticText        *m_LDDC2RBW;
    wxComboBox          *m_CBDDC2RBW;
    wxStaticText        *m_LAudioRBW;
    wxComboBox          *m_CBAudioRBW;
    wxStaticText        *m_LLocked;
    bool                m_Locked;

    TWaveOut            m_WaveOut;
    wxTimer             m_MeasurTimer;

    uint32_t            m_DemModeCount;

    wxStaticBox         *m_BoxVolume;
    wxSlider            *m_Volume;
    TIntEdit            *m_EVolume;
    wxToggleButton      *m_BMute;
        

    wxStaticBox         *m_BoxAGC;
    wxComboBox          *m_CBAGC;

    wxStaticBox         *m_BoxGain;
    TIntEdit            *m_EGain;
    wxStaticText        *m_LGaindB;

    wxStaticBox         *m_BoxSquelch;
    wxToggleButton      *m_BSquelch;
    TIntEdit            *m_ESquelch;
    wxStaticText        *m_LSquelchdB;
    bool                m_Squelched;
    wxStaticText        *m_LSquelched;

    wxStaticBox         *m_BoxAF;
    wxToggleButton      *m_BAF;
    wxStaticText        *m_LAFLow;
    TFrequencyEdit      *m_EAFLow;
    wxStaticText        *m_LAFHigh;
    TFrequencyEdit      *m_EAFHigh;
    wxStaticText        *m_LAFDeem;
    TFloatEdit          *m_EAFDeem;
    wxStaticText        *m_LAFDeemUnits;
    
    wxStaticBox         *m_BoxMeasur;
    wxStaticText        *m_LSlevel;
    wxStaticText        *m_LSlevelValue;
    wxStaticText        *m_LFreqError;
    wxStaticText        *m_LFreqErrorValue;
    wxStaticText        *m_LADCLevel;
    wxStaticText        *m_LADCLevelValue;
    wxStaticText        *m_LAMDepth;
    wxStaticText        *m_LAMDepthValue;
    wxStaticText        *m_LDeviation;
    wxStaticText        *m_LDeviationValue;
    wxStaticText        *m_LCurrentGain;
    wxStaticText        *m_LCurrentGainValue;

    wxStaticBox         *m_BoxAMSSideband;
    wxComboBox          *m_CBAMSSideband;

    wxStaticBox         *m_BoxDSBSideband;
    wxComboBox          *m_CBDSBSideband;

    wxStaticBox         *m_BoxISBSideband;
    wxComboBox          *m_CBISBSideband;

    wxStaticBox         *m_BoxCWTone;
    TFrequencyEdit      *m_ECWTone;

    wxStaticBox         *m_BoxFMW;
    wxToggleButton      *m_BFMWStereo;
    wxStaticText        *m_LFMWDeem;
    wxToggleButton      *m_BFMWDeem50;
    wxToggleButton      *m_BFMWDeem75;
    wxStaticText        *m_LStereo;
    bool                m_Stereo;

    void OnComboBoxChanged(wxCommandEvent &Event);
    void OnButtonClick(wxCommandEvent &Event);
    void OnTimer(wxTimerEvent& Event);
    void OnNumericEditChanged(wxNotifyEvent &Event);
    void OnSpectrumTune(TSpectrumTuneEvent &Event);
    void OnModeButtonClick(wxCommandEvent &Event);
    void OnSliderChanged(wxScrollEvent &Event);


    void UpdateDDC1(void);
    void UpdateDDC1RBWList(void);
    void UpdateDDC1RBW(void);
    void UpdateDDC1AbsFrequency(void);
    
    void UpdateDDC2(void);
    void UpdateDDC2List(void);
    void UpdateDDC2RBWList(void);
    void UpdateDDC2RBW(void);
    void UpdateDDC2Frequency(void);
    void UpdateDDC2AbsFrequency(void);

    void UpdateDemFrequency(void);
    void UpdateDemAbsFrequency(void);
    void UpdateDemBandwidth(void);
    void UpdateDemMode(void);
    void UpdateDemAMSSideband(void);
    void UpdateDemDSBSideband(void);
    void UpdateDemISBSideband(void);
    void UpdateDemCWTone(void);
    void UpdateDemFMWStereo(void);
    void UpdateDemFMWDeemphasis(void);

    void UpdateAudio(void);
    void UpdateAudioRBWList(void);
    void UpdateAudioRBW(void);
    void UpdateAudioVolume(void);
    void UpdateAudioMute(void);
    void UpdateAudioFilter(void);
    void UpdateAudioFilterParams(void);

    void UpdateAGC(void);
    void UpdateGain(void);

    void ShowMeasurements(void);
    

    DECLARE_EVENT_TABLE()
};

#endif