/* ***********************************************************************/
/*                                                                       */
/*                      WiNRADiO G39DDC EXCELSIOR                        */
/*      Compat ioctl codes and definitions for G39DDC device driver      */
/*                     (C) Copyright 2015 RADIXON.                       */
/*                                                                       */
/* ***********************************************************************/

#ifndef __G39_IOCTL_COMPAT_H__
#define __G39_IOCTL_COMPAT_H__

#ifdef CONFIG_COMPAT

#pragma pack(push,1)

struct g39_usb_control1_compat
{
    uint16_t        params[3];
    compat_uptr_t   buffer;
    uint16_t        size;
    compat_uptr_t   transferred;
};

struct g39_usb_control2_compat
{
    compat_uptr_t   buffer;
    uint16_t        size;
    compat_uptr_t   transferred;
};

struct g39_fpga_data_compat
{
    compat_uptr_t   buffer;
    uint32_t        size;
};

struct g39_spi_registers_compat
{
    uint16_t        count;
    uint16_t        id;
    compat_uptr_t   regs;
};

struct g39_spi2_registers_compat
{
    uint16_t        count;
    uint16_t        id;
    compat_uptr_t   regs;
};

struct g39_ddc1_start_params_compat
{
    uint32_t                buffer_size;
    uint32_t                bytes_per_sec;
    struct g39_ddc1_params  params;
    compat_uptr_t           coeffs;
};

#pragma pack(pop)

#define G39_IOCTL_CONFIGURE_FPGA_COMPAT             _IOW(0x8C,0x03,struct g39_fpga_data_compat)
#define G39_IOCTL_SET_SPI_REGS_COMPAT               _IOW(0x8C,0x04,struct g39_spi_registers_compat)
#define G39_IOCTL_SET_SPI2_REGS_COMPAT              _IOW(0x8C,0x05,struct g39_spi2_registers_compat)
#define G39_IOCTL_IF_PUT_BUFFER_COMPAT              _IOW(0x8C,0x09,compat_uptr_t)
#define G39_IOCTL_IF_GET_BUFFER_COMPAT              _IOR(0x8C,0x0A,compat_uptr_t)

#define G39_IOCTL_DDC1_0_START_COMPAT               _IOW(0x8C,0x0C,struct g39_ddc1_start_params_compat)
#define G39_IOCTL_DDC1_0_PUT_BUFFER_COMPAT          _IOW(0x8C,0x0F,compat_uptr_t)
#define G39_IOCTL_DDC1_0_GET_BUFFER_COMPAT          _IOR(0x8C,0x10,compat_uptr_t)
#define G39_IOCTL_DDC1_1_START_COMPAT               _IOW(0x8C,0x11,struct g39_ddc1_start_params_compat)
#define G39_IOCTL_DDC1_1_PUT_BUFFER_COMPAT          _IOW(0x8C,0x14,compat_uptr_t)
#define G39_IOCTL_DDC1_1_GET_BUFFER_COMPAT          _IOR(0x8C,0x15,compat_uptr_t)

#define G39_IOCTL_DDC2_0_PUT_BUFFER_COMPAT          _IOW(0x8C,0x19,compat_uptr_t)
#define G39_IOCTL_DDC2_0_GET_BUFFER_COMPAT          _IOR(0x8C,0x1A,compat_uptr_t)
#define G39_IOCTL_DDC2_1_PUT_BUFFER_COMPAT          _IOW(0x8C,0x1E,compat_uptr_t)
#define G39_IOCTL_DDC2_1_GET_BUFFER_COMPAT          _IOR(0x8C,0x1F,compat_uptr_t)

#define G39_IOCTL_SWP_PUT_BUFFER_COMPAT             _IOW(0x8C,0x2A,compat_uptr_t)
#define G39_IOCTL_SWP_GET_BUFFER_COMPAT             _IOR(0x8C,0x2B,compat_uptr_t)

#define G39_IOCTL_DDC1_0_PLAYBACK_PUT_BUFFER_COMPAT _IOW(0x8C,0x32,compat_uptr_t)
#define G39_IOCTL_DDC1_0_PLAYBACK_GET_BUFFER_COMPAT _IOR(0x8C,0x33,compat_uptr_t)
#define G39_IOCTL_DDC1_1_PLAYBACK_PUT_BUFFER_COMPAT _IOW(0x8C,0x36,compat_uptr_t)
#define G39_IOCTL_DDC1_1_PLAYBACK_GET_BUFFER_COMPAT _IOR(0x8C,0x37,compat_uptr_t)

#define G39_IOCTL_DAC_PUT_BUFFER_COMPAT             _IOW(0x8C,0x40,compat_uptr_t)
#define G39_IOCTL_DAC_GET_BUFFER_COMPAT             _IOR(0x8C,0x41,compat_uptr_t)

#define G39_IOCTL_USB_CONTROL1_READ_COMPAT          _IOR(0x8C,0x60,struct g39_usb_control1_compat)
#define G39_IOCTL_USB_CONTROL1_WRITE_COMPAT         _IOW(0x8C,0x61,struct g39_usb_control1_compat)
#define G39_IOCTL_USB_CONTROL2_READ_COMPAT          _IOR(0x8C,0x62,struct g39_usb_control2_compat)
#define G39_IOCTL_USB_CONTROL2_WRITE_COMPAT         _IOW(0x8C,0x63,struct g39_usb_control2_compat)

#endif //CONFIG_COMPAT

#endif // __G39_IOCTL_COMPAT_H__
